@@ -20,13 +20,26 @@ class EasyLabel:
             self._label.pack(side=side, expand=expand, fill=fill, padx=padx, pady=pady, ipadx=ipadx, ipady=ipady,
                              anchor=anchor)
 
+    def set_text(self, text):
+        self._text = text
+        self._label.config(text=text)
+
     def get_label(self):
         return self._label
 
 
 if __name__ == "__main__":
     root = tkinter.Tk()
-    EasyAutoWindow(root, window_title="Label", window_width_value=200, window_height_value=50, adjust_x=False,
+    EasyAutoWindow(root, window_title="Label", window_width_value=200, window_height_value=100, adjust_x=False,
                    adjust_y=False)
-    EasyLabel(root, text="Label", expand=tkinter.YES)
+    l1 = EasyLabel(root, text="Label", expand=tkinter.YES)
+
+
+    def change_text():
+        l1.set_text("你好，世界！")
+
+
+    btn = tkinter.Button(root, text="切换", command=change_text)
+    btn.pack()
+
     root.mainloop()
